package
Version:
v0.0.0-...-bed4bf8
Opens a new window with list of versions in this module.
Published: Aug 24, 2025
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
EnableCORS bool
Proxy []Proxy `yaml:"proxy"`
}
type Proxy struct {
Host string `yaml:"host"`
Upstream string `yaml:"upstream"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.